//
//  Top3TableViewController.swift
//  Game
//
//  Created by Santiago Pavón on 8/12/14.
//  Copyright (c) 2014 UPM. All rights reserved.
//

import UIKit

let GAME_URL = "http://localhost:3000/scores/top3.json"

class Top3TableViewController: UITableViewController {

    // Los datos descargados:
    var top3Scores: [[String:Any]] = []
    
    
    @IBOutlet weak var refreshButton: UIBarButtonItem!
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
   
        getTop3()
    }


    // MARK: Acciones
    
    @IBAction func getTop3() {

        // Descomentar la sentencia que se quiera usar:
        
        //getTop3_sin_GCD()
        getTop3_con_GCD()
    }
    
    @IBAction func getTop3_con_GCD() {
        title = "Descargando..."
        refreshButton.isEnabled = false 
        UIApplication.shared.isNetworkActivityIndicatorVisible = true
        
        let queue = DispatchQueue(label: "download queue")
        
        queue.async {
            // No hay que escapar caracteres conflictivos
            let url = URL(string: GAME_URL)!
            
            if let jsonData = try? Data(contentsOf: url),
                let newTop3 = (try? JSONSerialization.jsonObject(with: jsonData)) as? [[String:Any]] {
                DispatchQueue.main.async {
                    self.top3Scores = newTop3
                    self.tableView.reloadData()
                    self.title = "Top 3"
                }
            } else {
                DispatchQueue.main.async {
                    self.title = "Desactualizado"
                }
            }
            DispatchQueue.main.async {
                self.refreshButton.isEnabled = true
                UIApplication.shared.isNetworkActivityIndicatorVisible = false
            }
        }
    }

    @IBAction func getTop3_sin_GCD() {
        
        title = "Descargando..."
        refreshButton.isEnabled = false
        UIApplication.shared.isNetworkActivityIndicatorVisible = true
        
        let url = URL(string: GAME_URL)!
        
        if let jsonData = try? Data(contentsOf: url),
            let newTop3 = (try? JSONSerialization.jsonObject(with: jsonData)) as? [[String:Any]] {
            top3Scores = newTop3
            tableView.reloadData()
            title = "Top 3"
        } else {
            title = "Desactualizado"
        }
        
        self.refreshButton.isEnabled = true
        UIApplication.shared.isNetworkActivityIndicatorVisible = false
    }

    
    // MARK: - Table view data source

    override func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }

    override func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return top3Scores.count
    }

    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "Score Cell", for: indexPath) 

        let dic = top3Scores[indexPath.row]

        cell.textLabel?.text = dic["name"] as? String
        let total = dic["total"] as! Int
        cell.detailTextLabel?.text = "\(total)"
        
        return cell
    }
}
